@@ -8,7 +8,6 @@ use Config::Simple '-strict';
 use File::Path;
 use File::pushd;
 use DateTime;
-use Image::Magick;
 use Publican;
 use Publican::Builder;
 use Term::ANSIColor qw(:constants uncolor);
@@ -18,7 +17,7 @@ use vars qw( $VERSION $MAX_COUNT );
 $VERSION   = '0.2';
 $MAX_COUNT = 29;
 
-my $INIT_VERSION  = '0.1';
+my $INIT_VERSION = '0.1';
 
 ## NOTE Change this for betas
 my $PUBLICAN_NAME = 'publican';
@@ -73,13 +72,14 @@ sub new {
 
     if ( %{$args} ) {
         croak(
-            maketext( "unknown arguments: [_1]", join( ", ", keys %{$args} ) ) );
+            maketext(
+                "unknown arguments: [_1]", join( ", ", keys %{$args} )
+            )
+        );
     }
 
-
     $config->param( 'type',    'brand' );
     $config->param( 'version', $INIT_VERSION );
-    $config->param( 'release', '0' );
 
     my $self = bless {}, $class;
 
@@ -106,7 +106,9 @@ sub create {
         unless ( Publican::valid_lang($lang) );
 
     croak(
-        maketext( "Can't create brand, directory 'publican-[_1]' exists!", $name )
+        maketext(
+            "Can't create brand, directory 'publican-[_1]' exists!", $name
+        )
     ) if ( -d "publican-$name" );
 
     mkpath("publican-$name")
@@ -116,6 +118,9 @@ sub create {
         || croak( maketext( "Can't create directory: [_1]", $@ ) );
 
     $self->conf_files();
+
+    $self->{publican} = Publican->new( { configfile => 'publican.cfg', } );
+
     $self->xml_files();
     $self->images();
 
@@ -140,8 +145,8 @@ h1 {
 	color:#a70000;
 }
 
-.producttitle {
-	background: #800 url(../images/h1-bg.png) top left repeat;
+div.producttitle {
+	color:#a70000;
 }
 
 .section h1.title {
@@ -177,7 +182,7 @@ table tr.even td {
 	color:#a70000;
 }
 
-.edition {
+.titlepage .edition {
 	color: #a70000;
 }
 
@@ -246,7 +251,7 @@ sub xml_files {
             maketext( "Could not open file [_1] for output!", $out_file ) );
 
         print( $OUTDOC Publican::Builder::dtd_string(
-                { tag => $type, dtdver => '4.5' }
+                { tag => $type, dtdver => '4.5', cleaning => 1 }
             )
         );
         print( $OUTDOC $text );
@@ -278,8 +283,8 @@ sub conf_files {
     $self->{config}->write($cfg_file)
         || croak(
         maketext(
-            "Can't write to [_1]: [_2]",
-            $cfg_file, Config::Simple->error()
+            "Can't write to [_1]: [_2]", $cfg_file,
+            Config::Simple->error()
         )
         );
 
@@ -292,16 +297,21 @@ sub conf_files {
     $config->param( 'doc_url',  'http://www.SETUP.example.com/docs' );
     $config->write('defaults.cfg')
         || croak(
-        maketext( "Can't write to defaults.cfg: [_1]", Config::Simple->error() )
+        maketext(
+            "Can't write to defaults.cfg: [_1]",
+            Config::Simple->error()
+        )
         );
     $config->close();
 
     $config = new Config::Simple();
     $config->syntax('http');
-    $config->param( 'strict', 0 );
     $config->write('overrides.cfg')
         || croak(
-        maketext( "Can't write to overrides.cfg: [_1]", Config::Simple->error() )
+        maketext(
+            "Can't write to overrides.cfg: [_1]",
+            Config::Simple->error()
+        )
         );
     $config->close();
 
@@ -310,10 +320,12 @@ sub conf_files {
     $out_file = "publican-$lcbrand.spec";
 
     open( $OUT, ">:encoding(UTF-8)", $out_file )
-        || croak( maketext( "Could not open file [_1] for output!", $out_file ) );
+        || croak(
+        maketext( "Could not open file [_1] for output!", $out_file ) );
 
     print $OUT <<SPEC;
 %define brand $brand
+%define wwwdir /var/www/html/docs
 
 Name:		publican-$lcbrand
 Summary:	Common documentation files for %{brand}
@@ -324,14 +336,22 @@ Group:		Applications/Text
 Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
 Buildarch:	noarch
 Source:		https://www.SETUP.set.me.example.com/source/%{name}-%{version}.tgz
-Requires:	$PUBLICAN_NAME >= 1.99
-BuildRequires:	$PUBLICAN_NAME >= 1.99
+Requires:	$PUBLICAN_NAME
+BuildRequires:	$PUBLICAN_NAME
 URL:		https://www.SETUP.set.me.example.com
 
 %description
 This package provides common files and templates needed to build documentation
 for %{brand} with publican.
 
+%package web
+Summary:        Web styles for the %{brand} brand
+Group:          Documentation
+Requires:	$PUBLICAN_NAME
+
+%description web
+Web Site common files for the %{brand} brand.
+
 %prep
 %setup -q 
 
@@ -342,6 +362,9 @@ publican build --formats=xml --langs=all --publish
 rm -rf \$RPM_BUILD_ROOT
 mkdir -p -m755 \$RPM_BUILD_ROOT%{_datadir}/$PUBLICAN_NAME/Common_Content
 publican install_brand --path=\$RPM_BUILD_ROOT%{_datadir}/$PUBLICAN_NAME/Common_Content
+mkdir -p -m755 \$RPM_BUILD_ROOT/%{wwwdir}/%{brand}
+publican install_brand --web --path=\$RPM_BUILD_ROOT/%{wwwdir}/%{brand}
+
 
 %clean
 rm -rf \$RPM_BUILD_ROOT
@@ -352,6 +375,10 @@ rm -rf \$RPM_BUILD_ROOT
 %doc COPYING
 %{_datadir}/$PUBLICAN_NAME/Common_Content/%{brand}
 
+%files web
+%defattr(-,root,root,-)
+%{wwwdir}/%{brand}
+
 %changelog
 * $date  SETUP:YourName <SETUP:your.email\@example.com> 0.1
 - Created Brand
@@ -361,15 +388,16 @@ SPEC
     close($OUT);
 
     open( $OUT, ">:encoding(UTF-8)", 'README' )
-        || croak( maketext( "Could not open file README for output!" ) );
+        || croak( maketext("Could not open file README for output!") );
 
-    print($OUT "SETUP This file should be a short description of your project");
+    print( $OUT
+            "SETUP This file should be a short description of your project" );
     close($OUT);
 
     open( $OUT, ">:encoding(UTF-8)", 'COPYING' )
-        || croak( maketext( "Could not open file COPYING for output!" ) );
+        || croak( maketext("Could not open file COPYING for output!") );
 
-    print($OUT "SETUP This file should contain your COPYRIGHT License");
+    print( $OUT "SETUP This file should contain your COPYRIGHT License" );
     close($OUT);
 
     return;
@@ -387,156 +415,9 @@ sub images {
     my ( $OUT, $out_file );
     my $lang = $self->{config}->param('xml_lang');
 
-    # create call out numbers
-    for ( my $count = 1; $count <= $MAX_COUNT; $count++ ) {
-        my $svg = <<SVG;
-<?xml version="1.0" encoding="UTF-8" standalone="no"?>
-
-<svg
-   xmlns:svg="http://www.w3.org/2000/svg"
-   xmlns="http://www.w3.org/2000/svg"
-   version="1.0"
-   width="32"
-   height="32"
-   id="svg$count">
-  <defs
-     id="defs$count" />
-  <circle
-     cx="16"
-     cy="16"
-     r="14"
-     id="circle"
-     style="fill:#aa0000" />
-  <text
-     x="16"
-     y="16"
-     transform="scale(0.89833804,1.1131667)"
-     id="text$count"
-     xml:space="preserve"
-     style="font-size:20px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:middle;fill:#ffffff;fill-opacity:1;stroke:none;font-family:Liberation Serif;"><tspan
-       x="18"
-       y="20"
-       id="tspan$count">$count</tspan></text>
-</svg>
-SVG
-
-        open( $OUT, ">:encoding(UTF-8)", "$lang/images/$count.svg" )
-            || croak(
-            maketext(
-                "Can't open SVG file [_1]: [_2]", "$lang/images/$count.svg",
-                $@
-            )
-            );
-        print( $OUT $svg );
-        close($OUT);
-        my $image = Image::Magick->new;
-        $image->ReadImage("$lang/images/$count.svg");
-        $image->Write("$lang/images/$count.png");
-    }
-
-    my %images = (
-
-        # Nav images
-        'stock-go-back'    => { x => 22, y => 22 },
-        'stock-go-forward' => { x => 22, y => 22 },
-        'stock-go-up'      => { x => 22, y => 22 },
-        'stock-home'       => { x => 22, y => 22 },
-
-        # Logo images
-        'image_left'  => { x => 88,  y => 45 },
-        'image_right' => { x => 199, y => 41 },
-        'title_logo'  => { x => 112, y => 100 },
-        'h1-bg'       => { x => 5,   y => 100 },
-
-        # Admonition images
-        'important' => { x => 48, y => 48 },
-        'note'      => { x => 48, y => 48 },
-        'warning'   => { x => 48, y => 48 },
-
-        # List style images
-        'dot2' => { x => 5, y => 6 },
-        'dot'  => { x => 5, y => 6 },
-
-        # Watermark
-        'watermark-draft' => { x => 500, y => 500 },
-    );
-
-    foreach my $image ( keys(%images) ) {
-        $self->default_images(
-            {   file => $image,
-                x    => $images{$image}->{x},
-                y    => $images{$image}->{y}
-            }
-        );
-    }
-
-    return;
-}
-
-=head2 default_images
-
-Generate images with default text in SVG and PNG formats.
-
-=cut
-
-sub default_images {
-    my ( $self, $args ) = @_;
-
-    my $file = delete( $args->{file} )
-        || croak( maketext("file is a mandatory argument") );
-    my $x = delete( $args->{x} )
-        || croak( maketext("x is a mandatory argument") );
-    my $y = delete( $args->{y} )
-        || croak( maketext("y is a mandatory argument") );
-
-    if ( %{$args} ) {
-        croak(
-            maketext( "unknown arguments: [_1]", join( ", ", keys %{$args} ) ) );
-    }
-
-    my ($OUT);
-    my $lang = $self->{config}->param('xml_lang');
-
-    my $x1 = $x / 2;
-    my $x2 = $x1 + 2;
-    my $y1 = $y / 2;
-    my $y2 = $y1 + 2;
-
-    my $svg = <<SVG;
-<?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<svg
-   xmlns:svg="http://www.w3.org/2000/svg"
-   xmlns="http://www.w3.org/2000/svg"
-   version="1.0"
-   width="$x"
-   height="$y"
-   id="svg$file">
-  <defs
-     id="defs$file" />
-  <text
-     x="$x1"
-     y="$y1"
-     transform="scale(0.89833804,1.1131667)"
-     id="text$file"
-     xml:space="preserve"
-     style="font-size:20px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:middle;fill:#ffffff;fill-opacity:1;stroke:none;font-family:Liberation Serif;"><tspan
-       x="$x2"
-       y="$y2"
-       id="tspan$file">$file</tspan></text>
-</svg>
-SVG
-
-    open( $OUT, ">:encoding(UTF-8)", "$lang/images/$file.svg" )
-        || croak(
-        maketext(
-            "Can't open SVG file [_1]: [_2]", "$lang/images/$file.svg", $@
-        )
-        );
-    print( $OUT $svg );
-    close($OUT);
-    my $image = Image::Magick->new;
-    $image->ReadImage("$lang/images/$file.svg");
-    $image->Write("$lang/images/$file.png");
+    my $common_content = $self->{publican}->param('common_content');
+    rcopy_glob( $common_content . "/brand-template/images/*",
+        "$lang/images" );
 
     return;
 }
@@ -587,7 +468,6 @@ Config::Simple
 File::Path
 File::pushd
 DateTime
-Image::Magick
 Publican
 Term::ANSIColor
 
