@@ -4,15 +4,17 @@ use utf8;
 use strict;
 use warnings;
 use 5.008;
-use Carp;
+use Carp qw(carp croak cluck);
 use Publican;
 use Publican::Builder;
-use File::Copy::Recursive qw(fcopy rcopy dircopy fmove rmove dirmove);
+use Publican::Localise;
 use File::Path;
 use Term::ANSIColor qw(:constants);
 use DateTime;
 use Locale::PO;
 use XML::TreeBuilder;
+use String::Similarity;
+use Encode qw(is_utf8 decode_utf8 encode_utf8);
 
 use vars qw($VERSION);
 
@@ -20,10 +22,11 @@ $VERSION = '0.2';
 
 # What tags do we translate?
 my $TRANSTAGS
-    = qr/^(?:ackno|bridgehead|caption|conftitle|contrib|entry|firstname|glossterm|indexterm|jobtitle|keyword|label|lastname|lineannotation|lotentry|member|orgdiv|orgname|othername|para|phrase|productname|refclass|refdescriptor|refentrytitle|refmiscinfo|refname|refpurpose|releaseinfo|revremark|screeninfo|secondaryie|seealsoie|seeie|seg|segtitle|simpara|subtitle|surname|term|termdef|tertiaryie|title|titleabbrev|screen|programlisting|literallayout)$/;
+    = qr/^(?:ackno|bridgehead|caption|conftitle|contrib|entry|firstname|glossterm|indexterm|jobtitle|keyword|label|lastname|lineannotation|lotentry|member|orgdiv|orgname|othername|para|phrase|productname|refclass|refdescriptor|refentrytitle|refmiscinfo|refname|refpurpose|releaseinfo|revremark|screeninfo|secondaryie|seealsoie|seeie|seg|segtitle|simpara|subtitle|surname|term|termdef|tertiaryie|textobject|title|titleabbrev|screen|programlisting|literallayout)$/;
 
 # Blocks that contain translatable tags that need to be kept inline
-my $IGNOREBLOCKS = qr/^(?:footnote|citerefentry|indexterm|productname|phrase)$/;
+my $IGNOREBLOCKS
+    = qr/^(?:footnote|citerefentry|indexterm|orgname|productname|phrase|textobject)$/;
 
 # Preserve white space in these tags
 my $VERBATIM = qr/^(?:screen|programlisting|literallayout)$/;
@@ -73,6 +76,35 @@ sub new {
     return $self;
 }
 
+=head2 trans_drop
+
+Snapshot the source to give translation a stable base.
+
+=cut
+
+sub trans_drop {
+    my ($self) = shift();
+
+    my $trans_drop = 'trans_drop';
+
+    mkdir $trans_drop if ( !-d $trans_drop );
+
+    my $source_dir = $self->{publican}->param('xml_lang');
+
+    my @files = dir_list( $source_dir, '*' );
+    foreach my $file ( sort(@files) ) {
+        logger( "\t" . maketext( "Processing file [_1]", $file ) . "\n" );
+        my $new_file = $file;
+        $new_file =~ s/^$source_dir/$trans_drop/;
+        $new_file =~ m|^(.*)/[^/]+$|;
+        my $path = $1;
+        mkpath($path) if ( !-d $path );
+        fcopy( $file, $new_file );
+    }
+
+    return;
+}
+
 =head2 update_pot
 
 Update the pot files
@@ -84,15 +116,18 @@ sub update_pot {
 
     mkdir 'pot' if ( !-d 'pot' );
 
-    my $xml_lang = $self->{publican}->param('xml_lang');
-    my @xml_files = dir_list( $xml_lang, '*.xml' );
+    my $source_dir = $self->{publican}->param('xml_lang');
+    $source_dir = 'trans_drop' if ( -d 'trans_drop' );
+    my $extras = $self->{publican}->param('extras_dir');
+
+    my @xml_files = dir_list( $source_dir, '*.xml' );
     foreach my $xml_file ( sort(@xml_files) ) {
-        next if ( $xml_file =~ m|$xml_lang/extras/| );
-        next if ( $xml_file =~ m|$xml_lang/Legal_Notice.xml| );
+        next if ( $xml_file =~ m|$source_dir/$extras/| );
+        next if ( $xml_file =~ m|$source_dir/Legal_Notice.xml| );
         logger( "\t" . maketext( "Processing file [_1]", $xml_file ) . "\n" );
         my $pot_file = $xml_file;
         $pot_file =~ s/\.xml/\.pot/;
-        $pot_file =~ s/^$xml_lang/pot/;
+        $pot_file =~ s/^$source_dir/pot/;
         $pot_file =~ m|^(.*)/[^/]+$|;
         my $path = $1;
         mkpath($path) if ( !-d $path );
@@ -104,11 +139,20 @@ sub update_pot {
         $xml_doc->pos( $xml_doc->root() );
 
         my $msg_list = $self->get_msgs( { doc => $xml_doc } );
-##debug_msg( "hash: " . join( "\n\n", keys( %{$msgids} ) ) . "\n\n" );
+##debug_msg( "hash: " . $msg_list->content_list() . "\n\n" );
         $self->print_msgs( { msg_list => $msg_list, pot_file => $pot_file } );
 
         # Remove pot files with no content
-        unlink($pot_file) if ( -z $pot_file );
+        if ( ( -z $pot_file ) || ( $msg_list->content_list() == 0 ) ) {
+            unlink($pot_file);
+            logger(
+                "\t"
+                    . maketext(
+                    "deleted empty pot file: [_1]" . "\n", $pot_file
+                    )
+            );
+        }
+
     }
 
     return;
@@ -154,6 +198,7 @@ sub po2xml {
 
     my $msgids = Locale::PO->load_file_ashash($po_file);
     foreach my $key ( keys( %{$msgids} ) ) {
+##debug_msg("key: $key\n");
 ##debug_msg("is utf8  key " . utf8::is_utf8($key) . "\n");
         my $msgref = $msgids->{$key};
 ##debug_msg("is utf8 msgref " . utf8::is_utf8($msgref->msgstr()) . "\n");
@@ -171,6 +216,11 @@ sub po2xml {
 
     $self->merge_msgs( { out_doc => $out_doc, msgids => $msgids } );
 
+    $out_doc->pos( $out_doc->root() );
+    foreach my $node ( $out_doc->look_down( 'processed', 1 ) ) {
+        $node->attr( 'processed', undef );
+    }
+
     $out_doc->pos( $out_doc->root() );
     my $type = $out_doc->attr("_tag");
     my $text = $out_doc->as_XML();
@@ -193,7 +243,7 @@ sub po2xml {
     open( $OUTDOC, ">:encoding(UTF-8)", "$out_file" )
         || croak( maketext( "Could not open [_1] for output!", $out_file ) );
     print $OUTDOC Publican::Builder::dtd_string(
-        { tag => $type, dtdver => $dtdver } );
+        { tag => $type, dtdver => $dtdver, cleaning => 1 } );
 ##debug_msg("is utf8 text: " . utf8::is_utf8($text) . "\n");
     print( $OUTDOC $text );
     close($OUTDOC);
@@ -203,7 +253,7 @@ sub po2xml {
 
 =head2 update_po
 
-Update the PO files using msgmerge
+Update the PO files using internal process or msgmerge
 
 =cut
 
@@ -213,6 +263,14 @@ sub update_po {
     my $langs = delete( $args->{langs} )
         || croak( maketext("langs is a mandatory argument") );
 
+    my $msgmerge  = delete( $args->{msgmerge} );
+    my $firstname = delete( $args->{firstname} )
+        || croak( maketext("firstname is a mandatory argument") );
+    my $surname = delete( $args->{surname} )
+        || croak( maketext("surname is a mandatory argument") );
+    my $email = delete( $args->{email} )
+        || croak( maketext("email is a mandatory argument") );
+
     if ( %{$args} ) {
         croak(
             maketext(
@@ -221,15 +279,18 @@ sub update_po {
         );
     }
 
-    my $docname  = $self->{publican}->param('docname');
-    my $version  = $self->{publican}->param('version');
-    my $type     = $self->{publican}->param('type');
-    my $xml_lang = $self->{publican}->param('xml_lang');
+    my $docname    = $self->{publican}->param('docname');
+    my $version    = $self->{publican}->param('version');
+    my $type       = $self->{publican}->param('type');
+    my $xml_lang   = $self->{publican}->param('xml_lang');
+    my $source_dir = $xml_lang;
+    $source_dir = 'trans_drop' if ( -d 'trans_drop' );
 
     my @pot_files = dir_list( 'pot', '*.pot' );
 
     foreach my $lang ( sort( split( /,/, $langs ) ) ) {
         next if ( $lang eq $xml_lang );
+        next if ( $lang eq $source_dir );
 
         unless ( Publican::valid_lang($lang) ) {
             logger(
@@ -238,6 +299,19 @@ sub update_po {
             next;
         }
 
+        my $lc_lang = $lang;
+        $lc_lang =~ s/-/_/g;
+        my $locale = Publican::Localise->get_handle($lc_lang)
+            || croak(
+            maketext(
+                "Could not create a Publican::Localise object for language: [_1]",
+                $lang
+            )
+            );
+        $locale->encoding("UTF-8");
+        $locale->textdomain("publican");
+##        $locale->die_for_lookup_failures(1);
+
         # If asked to update a  non-existing language, create it
         mkdir $lang if ( !-d $lang );
 
@@ -262,8 +336,15 @@ sub update_po {
                 fcopy( $pot_file, $po_file );
             }
             else {
-                if (system(
-                        "msgmerge --no-wrap --quiet --backup=none --update $po_file $pot_file"
+                if ( !$msgmerge ) {
+                    $self->merge_po(
+                        { po_file => $po_file, pot_file => $pot_file } );
+                }
+                elsif (
+                    system(
+                        "msgmerge",      "--no-wrap", "--quiet",
+                        "--backup=none", "--update",  $po_file,
+                        $pot_file
                     ) != 0
                     )
                 {
@@ -277,9 +358,8 @@ sub update_po {
                 }
             }
 
-##            system("msgfmt -c -f --statistics $po_file");
             my $xml_file = $pot_file;
-            $xml_file =~ s/^pot/$xml_lang/;
+            $xml_file =~ s/^pot/$source_dir/;
             $xml_file =~ s/pot$/xml/;
             logger(
                 maketext( "WARNING: No source xml file exists for [_1]",
@@ -288,11 +368,157 @@ sub update_po {
                 CYAN
             ) unless ( -f $xml_file );
         }
+
+        if ( $self->{publican}->param('type') ne 'brand' ) {
+            my ( $edition, $release )
+                = $self->{publican}->get_ed_rev( { lang => $source_dir } );
+
+            my @members = (
+                decode_utf8(
+                    $locale->maketext(
+                        "Translation files synchronised with XML sources [_1]-[_2]",
+                        $edition,
+                        $release
+                    )
+                )
+            );
+
+            my $rev_num = "$edition-$release.1";
+            my ( $t_edition, $t_release );
+            eval {
+                ( $t_edition, $t_release )
+                    = $self->{publican}->get_ed_rev( { lang => $lang } );
+            };
+
+            if (   ( !$@ )
+                && ( $t_edition eq $edition )
+                && ( $t_release =~ /^$release\.(\d+)$/ ) )
+            {
+                $rev_num = "$edition-$release." . ( 1 + $1 );
+            }
+
+            $self->{publican}->add_revision(
+                {   lang      => $lang,
+                    revnumber => "$rev_num",
+                    members   => \@members,
+                    email     => $email,
+                    firstname => $firstname,
+                    surname   => $surname
+                }
+            );
+        }
+
     }
 
     return;
 }
 
+=head2 merge_po
+
+Merge updated POT files in to existing PO files.
+
+TODO Impliment this...
+
+=cut
+
+sub merge_po {
+    my ( $self, $args ) = @_;
+
+    my $po_file = delete( $args->{po_file} )
+        || croak( maketext("po_file is a mandatory argument") );
+    my $pot_file = delete( $args->{pot_file} )
+        || croak( maketext("pot_file is a mandatory argument") );
+
+    if ( %{$args} ) {
+        croak(
+            maketext(
+                "unknown arguments: [_1]", join( ", ", keys %{$args} )
+            )
+        );
+    }
+
+    my $pot_arry      = Locale::PO->load_file_asarray($pot_file);
+    my $po_hash       = Locale::PO->load_file_ashash($po_file);
+    my @po_keys       = keys( %{$po_hash} );
+    my %po_start_keys = map { $_ => 1 } @po_keys;
+    my @out_arry      = ();
+
+POT:
+    foreach my $pot ( @{$pot_arry} ) {
+        my $pot_id  = $pot->msgid();
+        my $matched = 0;
+        my %highest = ();
+        foreach my $po_id (@po_keys) {
+            my $match = $self->match_strings( $pot_id, $po_id );
+            if ( $match >= 1 ) {
+                delete( $po_start_keys{$po_id} );
+                $po_hash->{$po_id}->obsolete(0)
+                    if ( $po_hash->{$po_id}->obsolete() );
+                $po_hash->{$po_id}->fuzzy(0)
+                    if ( $po_hash->{$po_id}->fuzzy() );
+                push( @out_arry, $po_hash->{$po_id} );
+                next POT;
+            }
+            elsif ( $match >= 0.8 ) {
+                $matched = 1;
+                delete( $po_start_keys{$po_id} );
+                if (   ( !defined( $highest{match} ) )
+                    || ( $match > $highest{match} ) )
+                {
+                    $highest{match}  = $match;
+                    $highest{pot_id} = $pot_id;
+                    $highest{po_id}  = $po_id;
+                }
+            }
+        }
+
+        if ( !$matched ) {
+            push( @out_arry, $pot );
+        }
+        else {
+            my $id = $highest{po_id};
+            $po_hash->{$id}->fuzzy(1) unless ( $po_hash->{$id}->fuzzy() );
+            $po_hash->{$id}->obsolete(0) if ( $po_hash->{$id}->obsolete() );
+            $po_hash->{$id}
+                ->msgid( $po_hash->{$id}->dequote( $highest{pot_id} ) );
+            push( @out_arry, $po_hash->{$id} );
+        }
+    }
+
+    foreach my $obsolete ( keys(%po_start_keys) ) {
+        $po_hash->{$obsolete}->obsolete(1);
+        push( @out_arry, $po_hash->{$obsolete} );
+    }
+
+    Locale::PO->save_file_fromarray( $po_file, \@out_arry );
+
+    return;
+}
+
+=head2 match_strings
+
+Compare 2 strings and return how closely they match.
+
+Returns a vlaue between 0 and 1, weighted for string length.
+
+=cut
+
+sub match_strings {
+    my ( $self, $s1, $s2 ) = @_;
+
+    croak(
+        maketext(
+            "match_strings requires 2 arguments [_1], [_2].", $s1, $s2
+        )
+    ) unless ( ($s1) && ($s2) && ( $s1 ne "" ) && ( $s2 ne "" ) );
+
+    my $similarity = similarity( $s1, $s2 );
+
+## TODO factor string length in to similarity?
+
+    return ($similarity);
+}
+
 =head2 update_po_all
 
 Update the PO files for all languages
@@ -302,13 +528,27 @@ Update the PO files for all languages
 sub update_po_all {
     my ( $self, $args ) = @_;
 
-#    my $lang = delete( $args->{lang} ) || croak("lang is a mandatory argument");
-#
-#    if ( %{$args} ) {
-#        croak( maketext("unknown arguments: [_1]", join( ", ", keys %{$args}) ));
-#    }
+    my $msgmerge  = delete( $args->{msgmerge} );
+    my $firstname = delete( $args->{firstname} );
+    my $surname   = delete( $args->{surname} );
+    my $email     = delete( $args->{email} );
 
-    $self->update_po( { langs => get_all_langs() } );
+    if ( %{$args} ) {
+        croak(
+            maketext(
+                "unknown arguments: [_1]", join( ", ", keys %{$args} )
+            )
+        );
+    }
+
+    $self->update_po(
+        {   langs     => get_all_langs(),
+            msgmerge  => $msgmerge,
+            email     => $email,
+            firstname => $firstname,
+            surname   => $surname,
+        }
+    );
     return;
 }
 
@@ -330,7 +570,8 @@ sub get_msgs {
         );
     }
 
-    my $trans_tree = XML::TreeBuilder->new( { 'NoExpand' => "1", 'ErrorContext' => "2" });
+    my $trans_tree = XML::TreeBuilder->new(
+        { 'NoExpand' => "1", 'ErrorContext' => "2" } );
 
     my $trans_node;
 
@@ -345,16 +586,17 @@ sub get_msgs {
                 my $inner = $_[0];
 ## an index term NOT in a translatable tag should be translated as a block.
 ## An indexterm in a translatable tag should be translated inline
-                if ( $inner->tag() =~ /indexterm|productname|phrase/ ) {
+                if ( $inner->tag() =~ /indexterm|orgname|productname|phrase/ )
+                {
                     not defined(
                         $inner->look_up(
                             '_tag',
                             qr/$IGNOREBLOCKS/,
                             sub {
                                 $_[0]->tag() =~ /$TRANSTAGS/
-                                    && $inner->parent()
-                                    && $inner->parent()->tag()
-                                    =~ /$TRANSTAGS/;
+                                    && $inner->look_up( '_tag',
+                                    qr/$TRANSTAGS/,
+                                    sub { $_[0]->pos() != $inner->pos() } );
                             },
                         )
                     );
@@ -369,12 +611,9 @@ sub get_msgs {
         )
         )
     {
-
-        # lookdown matches the root node
-        if ( $child->address() eq $trans_tree->address() ) {
-
-            #            next;
-        }
+## BUGBUG is this required here?
+##        next if ( $child->attr('processed') );
+##        $child->attr( 'processed', 1 );
 
         next if ( $child->is_empty );
 
@@ -494,11 +733,8 @@ sub merge_msgs {
         )
     {
 
-        # lookdown matches the root node
-        if ( $child->address() eq $out_doc->address() ) {
-
-            #            next;
-        }
+        next if ( $child->attr('processed') );
+        $child->attr( 'processed', 1 );
 
         next if ( $child->is_empty );
 
@@ -585,7 +821,7 @@ sub translate {
     my $msgid = $node->as_XML();
     my $tag   = $node->tag();
 
-    #debug_msg("msgid 1: |$msgid| |$tag|\n");
+##debug_msg("msgid 1: $tag, $msgid\n");
     my $attr_text = '';
 
 ##debug_msg("is utf8 msgid: ".utf8::is_utf8($msgid)."\n");
@@ -608,10 +844,13 @@ sub translate {
         $attr_text =~ s/\\//g;
     }
 
-##debug_msg("msgid 4: |$msgid| |$tag|\n");
+##debug_msg("msgid 4: $tag, $msgid\n");
+    # mixed mode tags, para, caption, can be empty at this point
+    if ( $msgid and ( $msgid eq '""' ) ) {
 
-    if (   $msgid
-        && $msgid ne '""'
+        #nop
+    }
+    elsif ( $msgid
         && defined $msgids->{$msgid} )
     {
         if ( $msgids->{$msgid}{msgstr} ne '""' ) {
@@ -627,10 +866,12 @@ sub translate {
 
 ##debug_msg("is utf8 repl: ".utf8::is_utf8($repl)."\n");
 ##debug_msg("repl: |$repl|\n");
-            my $dtd
-                = Publican::Builder::dtd_string(
-                { tag => $tag, dtdver => $self->{publican}->param('dtdver') }
-                );
+            my $dtd = Publican::Builder::dtd_string(
+                {   tag      => $tag,
+                    dtdver   => $self->{publican}->param('dtdver'),
+                    cleaning => 1
+                }
+            );
             my $new_tree = Publican::Builder::new_tree();
             $new_tree->parse(qq|$dtd<$tag$attr_text>$repl</$tag>|);
             $node->delete_content();
@@ -647,7 +888,11 @@ sub translate {
                     maketext("WARNING: Un-translated message in PO file."),
                     RED );
             }
-            logger( "\n" . $msgid . "\n\n", RED );
+            my $str = $msgid;
+            $str = substr( $str, 0, 64 ) . '...' if ( length($str) > 64 );
+            logger(
+                "\n" . $msgids->{$msgid}->loaded_line_number . ": $str\n\n",
+                RED );
         }
     }
     else {
@@ -744,8 +989,8 @@ Returns a valid PO header string.
 sub header {
     my $self = shift;
 
-    #    my $date = UnixDate( ParseDate("today"), "%Y-%m-%d %H:%M%z" );
-    my $date = DateTime->now->iso8601();
+    my $date
+        = DateTime->now( time_zone => "local" )->strftime("%Y-%m-%d %H:%M%z");
 
     my $string = <<POT;
 # 
@@ -793,7 +1038,7 @@ sub normalise {
 ##    $norm =~ s/&#9;//g;
 ##    $norm =~ s/&#38;([a-zA-Z-_0-9]+;)/&$1/g;
     $norm =~ s/&#38;/&amp;/g;
-    $norm =~ s/&amp;#x200B;/&#x200B;/g;
+##    $norm =~ s/&amp;#x200B;/&#x200B;/g;
 ##    $norm =~ s/&#x200B; &#x200B;/ /g;
 ##    $norm =~ s/&#x200B; / /g;
     $norm =~ s/&#60;/&lt;/g;
